-- -- COPYRIGHT NOTICE -- --
-- This work is covered by the LGPL License. You are
-- able to modify, distribute and sublicense this
-- work as long as you include the original or show
-- clearly how to obtain it.

-- NOTES:
-- - Filename:   Main.lua
-- - Written By: Trilesch and Digpoe
-- - Purpose:    Loads the CombatStatus plugin

-- Acquire Utility Functions
import("CombatStatus.Util.UtilFunctions")
for i, v in pairs(CombatStatus.Util) do
	getfenv()[i] = v -- put functions into global environment
end

-- Load prerequesites
local Turbine         = require("Turbine")
                        require("Turbine.Gameplay")
                        require("Turbine.UI")
                        require("Turbine.UI.Lotro")
local Translate       = require("CombatStatus.TranslateWidget.Translator")
local CreateInterface = require("CombatStatus.CombatGui.GuiCreator")
local ChatParser      = require("CombatStatus.ChatParser.ParseChat")
local Player          = Turbine.Gameplay.LocalPlayer:GetInstance()

LogMessage("Starting...")
main = CreateInterface()

dstats = {
	HTake = 0,
	HDone = 0,
	DTake = 0,
	DDone = 0
}

function Turbine.Chat.Received(sender, args)
	if args.ChatType == Turbine.ChatType.PlayerCombat then -- Incoming/Outgoing healing + Outgoing damage
		if ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_HEAL_SPELL) then -- Healing
			local spell   = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_HEAL_SPELL)
			local healing = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_HEAL_POINTS)
			local player  = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_HEAL_CASTER)
			
			if healing then -- make sure the heal actually healed.
				if player ~= Player:GetName() then -- incoming
					dstats.HTake = dstats.HTake + tonumber(healing)
					main.Stats.HealTakeText.Text = Translate("Heal.Taken")..": "..dstats.HTake
					--TODO: make bars resize
				else --outgoing	
					dstats.HDone = dstats.HDone + tonumber(healing)
					main.Stats.HealDoneText.Text = Translate("Heal.Done")..": "..dstats.HDone
					--TODO: make bars resize
				end
			end
		else -- Damage
			local type       = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_HIT_TYPE)
			local damage     = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_DAMAGE_DONE)
			local damageType = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_DAMAGE_TYPE)
			
			if type then -- make sure it was actually a hit
				if damage and damageType then -- make sure the damage was done
					dstats.DDone = dstats.DDone + tonumber(damage)
					main.Stats.DamageDoneText.Text = Translate("Damage.Done")..": "..dstats.DDone
					--TODO: make bars resize
				end
			end
		end
	elseif args.ChatType == Turbine.ChatType.EnemyCombat then -- Incoming damage
		local type       = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_HIT_TYPE)
		local damage     = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_DAMAGE_DONE)
		local damageType = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_DAMAGE_TYPE)
		local damageModf = ChatParser.ParseMessage(args.Message, ChatParser.ParserType.PARSE_DAMAGE_MODF)
		
		if type then -- make sure it was actually a hit
			if damage and damageType then -- make sure the damage was dnoe
				dstats.DTake = dstats.DTake + tonumber(damage)
				main.Stats.DamageTakeText.Text = Translate("Damage.Taken")..": "..dstats.DTake
				--TODO: make bars resize
			end
		end
	end
end